import argparse
import grpc
import numpy as np

from model_pb2 import Prediction
from model_pb2_grpc import UncertaintyServicerStub

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--hostname", type=str, default="localhost")
    parser.add_argument("--port", type=int, default=54242)
    args = parser.parse_args()

    # establish connection
    with grpc.insecure_channel(f'{args.hostname}:{args.port}') as channel:
        stub = UncertaintyServicerStub(channel)

        for v in range(2, 5):
            # construct data for demonstrations purposes
            x = np.random.random((v, v * 2)).astype(np.float32)
            
            # construct Prediction message as specified per model.proto
            req = Prediction(dims=x.shape, vals=x.flatten())

            # send request
            response = stub.calculate(req)

            print(f"stats ="
                  f"\n var: {response.variance},"
                  f"\n entropy: {response.entropy},"
                  f"\n mutual information: {response.mutual_information}")
